<?php
namespace Creativeblockquote;

use Creativeblockquote\PageSettings\Page_Settings;
define( "BWDBK_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDBK_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );

class ClassbwdbkBlockquote {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdbk_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdbk_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdbk_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdbk_the_blockquote_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdbk-blockquote.php' );
	}

	public function bwdbk_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDBKblockquote() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwdbk-blockquote-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdbk_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdbk-blockquote-category',
			[
				'title' => esc_html__( 'BWD Blockquote', 'bwdbk-blockquote' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdbk_all_assets_for_the_public(){
		wp_enqueue_style('font-awesome-5','https://use.fontawesome.com/releases/v5.3.0/css/all.css',array(),'5.3.0', 'all');
		
		$all_css_js_file = array(
            'bwdbk_blockquote_style_css' => array('bwdbk_path_define'=>BWDBK_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/style.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdbk_path_define'], null, '1.0', 'all');
        }
	}
	

	public function bwdbk_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdbk_blockquote_admin_icon_css' => array('bwdbk_path_admin_define'=>BWDBK_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdbk_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdbk_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdbk_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdbk_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdbk_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdbk_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
ClassbwdbkBlockquote::instance();